@@ -1,5 +1,5 @@
 package Time::Elapsed::Lang::DA;
-$Time::Elapsed::Lang::DA::VERSION = '0.33';
+$Time::Elapsed::Lang::DA::VERSION = '0.34';
 use strict;
 use warnings;
 use utf8;
@@ -50,7 +50,7 @@ Time::Elapsed::Lang::DA
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -64,6 +64,10 @@ Private module.
 
 Time::Elapsed::Lang::DA - Danish language file.
 
+=head1 DEPRECATION NOTICE
+
+This module is B<DEPRECATED>. Please use L<Time::Duration>.
+
 =head1 METHODS
 
 =head2 singular
@@ -78,7 +82,7 @@ L<Time::Elapsed>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
