@@ -1,10 +1,8 @@
 package Time::Elapsed::Lang::DE;
+$Time::Elapsed::Lang::DE::VERSION = '0.34';
 use strict;
 use warnings;
 use utf8;
-use vars qw( $VERSION );
-
-$VERSION = '0.32';
 
 sub singular {
    return qw/
@@ -44,11 +42,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-Time::Elapsed::Lang::DE - German language file.
+Time::Elapsed::Lang::DE
+
+=head1 VERSION
+
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -56,11 +58,16 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.32> of C<Time::Elapsed::Lang::DE>
-released on C<5 July 2016>.
-
 Private module.
 
+=head1 NAME
+
+Time::Elapsed::Lang::DE - German language file.
+
+=head1 DEPRECATION NOTICE
+
+This module is B<DEPRECATED>. Please use L<Time::Duration>.
+
 =head1 METHODS
 
 =head2 singular
@@ -75,15 +82,13 @@ L<Time::Elapsed>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 - 2016 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2007 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.0 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
