@@ -1,5 +1,5 @@
 package Time::Elapsed::Lang::FR;
-$Time::Elapsed::Lang::FR::VERSION = '0.33';
+$Time::Elapsed::Lang::FR::VERSION = '0.34';
 use strict;
 use warnings;
 use utf8;
@@ -49,7 +49,7 @@ Time::Elapsed::Lang::FR
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -63,6 +63,10 @@ Private module.
 
 Time::Elapsed::Lang::FR - French language file.
 
+=head1 DEPRECATION NOTICE
+
+This module is B<DEPRECATED>. Please use L<Time::Duration>.
+
 =head1 METHODS
 
 =head2 singular
@@ -77,7 +81,7 @@ L<Time::Elapsed>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
