@@ -1,5 +1,5 @@
 package Time::Elapsed::Lang::TR;
-$Time::Elapsed::Lang::TR::VERSION = '0.33';
+$Time::Elapsed::Lang::TR::VERSION = '0.34';
 use strict;
 use warnings;
 use vars qw( $VERSION        );
@@ -42,7 +42,7 @@ Time::Elapsed::Lang::TR
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -56,6 +56,10 @@ Private module.
 
 Time::Elapsed::Lang::TR - Turkish language file.
 
+=head1 DEPRECATION NOTICE
+
+This module is B<DEPRECATED>. Please use L<Time::Duration>.
+
 =head1 METHODS
 
 =head2 singular
@@ -70,7 +74,7 @@ L<Time::Elapsed>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
